@@ -24,7 +24,7 @@ class Domain(object):
         data = r.json()
         self.call_response = data
         if data['status'] != "OK":
-            raise Exception(data[u'error_message'])
+            raise Exception(data[u'message'])
    
         return data
 
