@@ -18,7 +18,7 @@ class Event(object):
         data = r.json()
         self.call_response = data
         if data['status'] != "OK":            
-            raise Exception(data[u'error_message'])
+            raise Exception(data[u'message'])
         return data
 
     def load(self):
