@@ -16,7 +16,7 @@ class Image(object):
         data = r.json()
         self.call_response = data
         if data['status'] != "OK":
-            raise Exception(data[u'error_message'])
+            raise Exception(data[u'message'])
    
         return data
 
